==> kubernetes-model-networking-5.1.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/networking/v1beta1/IngressListFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface IngressListFluent<A extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress item);
    public A setToItems(int index,io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress item);
    public A addToItems(io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress... items);
    public A addAllToItems(Collection<io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress> items);
    public A removeFromItems(io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress... items);
    public A removeAllFromItems(Collection<io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress> items);
    public A removeMatchingFromItems(Predicate<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress> getItems();
    public List<io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress> buildItems();
    public io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress buildItem(int index);
    public io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress buildFirstItem();
    public io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress buildLastItem();
    public io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress buildMatchingItem(Predicate<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBuilder> predicate);
    public A withItems(List<io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress> items);
    public A withItems(io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress... items);
    public Boolean hasItems();
    public IngressListFluent.ItemsNested<A> addNewItem();
    public IngressListFluent.ItemsNested<A> addNewItemLike(io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress item);
    public IngressListFluent.ItemsNested<A> setNewItemLike(int index,io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress item);
    public IngressListFluent.ItemsNested<A> editItem(int index);
    public IngressListFluent.ItemsNested<A> editFirstItem();
    public IngressListFluent.ItemsNested<A> editLastItem();
    public IngressListFluent.ItemsNested<A> editMatchingItem(Predicate<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.networking.v1beta1.IngressFluent<IngressListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}

==> kubernetes-model-networking-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/networking/v1beta1/IngressListFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface IngressListFluent<A extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress item);
    public A setToItems(int index,io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress item);
    public A addToItems(io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress... items);
    public A addAllToItems(Collection<io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress> items);
    public A removeFromItems(io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress... items);
    public A removeAllFromItems(Collection<io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress> items);
    public A removeMatchingFromItems(Predicate<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress> getItems();
    public List<io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress> buildItems();
    public io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress buildItem(int index);
    public io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress buildFirstItem();
    public io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress buildLastItem();
    public io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress buildMatchingItem(Predicate<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBuilder> predicate);
    public A withItems(List<io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress> items);
    public A withItems(io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress... items);
    public Boolean hasItems();
    public IngressListFluent.ItemsNested<A> addNewItem();
    public IngressListFluent.ItemsNested<A> addNewItemLike(io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress item);
    public IngressListFluent.ItemsNested<A> setNewItemLike(int index,io.fabric8.kubernetes.api.model.networking.v1beta1.Ingress item);
    public IngressListFluent.ItemsNested<A> editItem(int index);
    public IngressListFluent.ItemsNested<A> editFirstItem();
    public IngressListFluent.ItemsNested<A> editLastItem();
    public IngressListFluent.ItemsNested<A> editMatchingItem(Predicate<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.networking.v1beta1.IngressFluent<IngressListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
